@@ -116,14 +116,23 @@ KaiDiscipline* BonusDisciplineWindow::GetDiscipline(QString name)
 
 void BonusDisciplineWindow::ChooseSlot()
 {
+    CheckWeaponMasteryBonus();
+
     QString name = sender()->objectName();
     switch (m_Serie){
     case Book::Kai:
     case Book::Magnakai:
         {
             KaiDiscipline* d = GetDiscipline(name);
-            if (d)
+            if (d){
+                if (name == "Weaponmastery"){
+                    AddWeaponMastery();
+                    Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
+                    foreach (QString w, m_Elements)
+                        wm->Weapons.append(Weapon::GetClass(w));
+                }
                 m_Player->KaiDisciplines.append(d);
+            }
         }
         break;
     default:
@@ -196,19 +205,8 @@ void BonusDisciplineWindow::SelectSlot(bool selected)
 
     if (selected){
         QString name = sender()->objectName();
-        if (name == "Weaponmastery"){
-            QStringList weapons;
-            for (int i=Weapon::Dagger; i<=Weapon::Bow; i++)
-                weapons.append(Weapon::ClassDescription(i));
-
-            int number = 10 - m_Player->GetDisciplineCount();
-            SelectFromListWindow* dlg = new SelectFromListWindow(this, "Select weapons",
-                                                                 QString("Select %1 weapons for the Weaponmastery discipline").arg(number),
-                                                                 weapons, number);
-            dlg->exec();
-
-            m_Elements = dlg->GetSelected();
-        }
+        if (name == "Weaponmastery")
+            AddWeaponMastery();
     }
 
     foreach (QCheckBox* c, m_CheckButtons)
@@ -217,6 +215,41 @@ void BonusDisciplineWindow::SelectSlot(bool selected)
 }
 
 void BonusDisciplineWindow::OkSlot()
+{
+    CheckWeaponMasteryBonus();
+    foreach (QCheckBox* c, m_CheckButtons){
+        if (c->isChecked()){
+            KaiDiscipline* d = GetDiscipline(c->objectName());
+            if (d){
+                if (d->Name == "Weaponmastery"){
+                    Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
+                    foreach (QString w, m_Elements)
+                        wm->Weapons.append(Weapon::GetClass(w));
+                }
+                m_Player->KaiDisciplines.append(d);
+            }
+        }
+    }
+    accept();
+}
+
+
+void BonusDisciplineWindow::AddWeaponMastery()
+{
+    QStringList weapons;
+    for (int i=Weapon::Dagger; i<=Weapon::Bow; i++)
+        weapons.append(Weapon::ClassDescription(i));
+
+    int number = m_Player->GetDisciplineCount() == 0 ? 3 : m_Player->GetDisciplineCount() + 1 - 3;
+    SelectFromListWindow* dlg = new SelectFromListWindow(this, "Select weapons",
+                                                         QString("Select %1 weapons for the Weaponmastery discipline").arg(number),
+                                                         weapons, number);
+    dlg->exec();
+
+    m_Elements = dlg->GetSelected();
+}
+
+void BonusDisciplineWindow::CheckWeaponMasteryBonus()
 {
     // Check the Weaponmastery discipline to add a weapon:
     if (m_Player->HasDiscipline("Weaponmastery")){
@@ -235,19 +268,4 @@ void BonusDisciplineWindow::OkSlot()
         foreach (QString w, dlg->GetSelected())
             wm->Weapons.append(Weapon::GetClass(w));
     }
-
-    foreach (QCheckBox* c, m_CheckButtons){
-        if (c->isChecked()){
-            KaiDiscipline* d = GetDiscipline(c->objectName());
-            if (d){
-                if (d->Name == "Weaponmastery"){
-                    Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
-                    foreach (QString w, m_Elements)
-                        wm->Weapons.append(Weapon::GetClass(w));
-                }
-                m_Player->KaiDisciplines.append(d);
-            }
-        }
-    }
-    accept();
 }
