@@ -36,6 +36,8 @@ private:
 
     void ShowData();
     KaiDiscipline* GetDiscipline(QString name);
+    void AddWeaponMastery();
+    void CheckWeaponMasteryBonus();
 
 private slots:
     void ChooseSlot();
