@@ -34,7 +34,7 @@ QDataStream &operator<<(QDataStream &out, const Player &player)
 {
     out << player.BaseCombatSkill << player.BaseEndurance
         << player.Endurance << player.GoldCrowns << player.HasBackpack() << player.DeathsCount << player.TemporaryCombatSkillDelta
-        << player.Properties << player.CanHunt() << player.HasQuiver() << player.Arrows;
+        << player.Properties << player.CanHunt();
     return out;
 }
 
@@ -42,14 +42,12 @@ QDataStream &operator>>(QDataStream &in, Player &player)
 {
     bool backpack = true;
     bool canHunt  = true;
-    bool quiver = true;
     in >> player.BaseCombatSkill >> player.BaseEndurance
        >> player.Endurance >> player.GoldCrowns >> backpack >> player.DeathsCount >> player.TemporaryCombatSkillDelta
-       >> player.Properties >> canHunt >> quiver >> player.Arrows;
+       >> player.Properties >> canHunt;
 
     player.SetHasBackpack(backpack);
     player.SetCanHunt(canHunt);
-    player.SetHasQuiver(quiver);
 
     return in;
 }
@@ -223,6 +221,7 @@ BookWindow::BookWindow(QWidget *parent) :
     connect(ui->actionRules, SIGNAL(triggered()), this, SLOT(RulesSlot()));
     connect(ui->actionAbout, SIGNAL(triggered()), this, SLOT(AboutSlot()));
     connect(ui->actionMap, SIGNAL(triggered()), this, SLOT(MapSlot()));
+    connect(ui->actionRestart_book, SIGNAL(triggered()), this, SLOT(BookRestartSlot()));
     connect(ui->actionBookInfo, SIGNAL(triggered()), this, SLOT(BookInfoSlot()));
 
     m_RandomPicker = new RandomNumberPicker(this, ui->lblDice);
@@ -1242,6 +1241,16 @@ void BookWindow::BookInfoSlot()
     delete dlg;
 }
 
+void BookWindow::BookRestartSlot()
+{
+    if (CommonStatic::ConfirmMessage(this, "Confirm", "Do you want to restart the book?") == QMessageBox::Yes){
+        Load(GetBookSaveFilename(m_Book->Number));
+        QScriptValue objectValue = m_Engine.newQObject(m_Player);
+        m_Engine.globalObject().setProperty("Player", objectValue);
+        ShowSection(m_Section->Number);
+    }
+}
+
 void BookWindow::DisableFightButton()
 {
     ui->pbnFight->setEnabled(false);
