@@ -16,6 +16,7 @@ public:
     enum ChooseMode{
         ChooseMeal,
         ChooseItem,
+        ChooseItemExceptMeals,
         ChooseSpecialItem,
         ChooseWeapon
     };
@@ -38,7 +39,7 @@ private:
 
     void ShowItems();
 
-    void ShowBackpackItems();
+    void ShowBackpackItems(bool excludeMeals=false);
     void ShowSpecialItems();
     void ShowMeals();
     void ShowWeapons();
