@@ -1,4 +1,5 @@
 #include "book.h"
+#include "kaidiscipline.h"
 
 Enemy::Enemy(QObject *parent) :
     QObject(parent)
@@ -111,6 +112,25 @@ void Section::RemoveEnemies()
     Enemies.clear();
 }
 
+
+bool Section::RemoveItem(QString name)
+{
+    if (!name.isEmpty()){
+        Item* found = NULL;
+        foreach(Item* i, Items){
+            if (QString::compare(i->Name, name) == 0){
+                found = i;
+                break;
+            }
+        }
+        if (found){
+            Items.removeOne(found);
+            return true;
+        }
+    }
+    return false;
+}
+
 Book::Book(QObject *parent) :
     QObject(parent)
 {
@@ -215,6 +235,12 @@ bool Book::Load(QString filename, bool full)
 
     file.close();
     FileName = filename;
+
+    if (GetSerie() == Book::Magnakai)
+        LoreCircles::InitCircles();
+    else
+        LoreCircles::ClearCircles();
+
     return !xml.hasError();
 }
 
@@ -311,6 +337,8 @@ Weapon* Book::ParseWeapon(Section* section, QXmlStreamReader* reader)
     if (attrs.hasAttribute("canbeequipped"))
         w->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     w->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
+    w->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
+    w->SetRandomBonus(attrs.value("randombonus").toString().toInt());
 
     QString tclass = attrs.value("class").toString();
     QStringList ele = tclass.split(";");
@@ -343,8 +371,11 @@ Item* Book::ParseItem(Section* section, QXmlStreamReader* reader)
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
     i->SetIsArrow(attrs.value("isarrow").toString().toInt() == 1);
+    if (attrs.hasAttribute("quantity"))
+        i->SetQuantity(attrs.value("quantity").toString().toInt());
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
     i->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
+    i->SetRandomBonus(attrs.value("randombonus").toString().toInt());
     i->SetEnduranceDelta(attrs.value("endurancedelta").toString().toInt());
     i->SetEnduranceRestore(attrs.value("endurancerestore").toString().toInt());
     i->SetSize(attrs.value("size").toString().toInt());
@@ -375,8 +406,12 @@ ShopItem* Book::ParseShopItem(Section* section, QXmlStreamReader* reader)
         i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
+    i->SetIsArrow(attrs.value("isarrow").toString().toInt() == 1);
+    if (attrs.hasAttribute("quantity"))
+        i->SetQuantity(attrs.value("quantity").toString().toInt());
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
     i->SetCombatskillDelta(attrs.value("combatskilldelta").toString().toInt());
+    i->SetRandomBonus(attrs.value("randombonus").toString().toInt());
     i->SetEnduranceDelta(attrs.value("endurancedelta").toString().toInt());
     i->SetEnduranceRestore(attrs.value("endurancerestore").toString().toInt());
     i->SetSize(attrs.value("size").toString().toInt());
