@@ -92,6 +92,8 @@ public slots:
     int GetEnemiesCount();
     void RemoveEnemies();
     void SetMustEat(int value) { MustEat = value; }
+    // Remove one item from the section, returns true if the item has been removed
+    bool RemoveItem(QString name);
 };
 
 
@@ -104,7 +106,7 @@ public:
         Kai,
         Magnakai,
         GrandMaster,
-        NewOrder,
+        NewOrder
     };
 
     explicit Book(QObject *parent = 0);
