@@ -45,6 +45,20 @@ Item::Item(const Item& item) :
     Description = item.Description;
 }
 
+QString Item::GetDescription()
+{
+    if (!Description.isEmpty())
+        return Description;
+
+    if (GetIsQuiver() && GetArrows() > 0)
+        return QString("Contains %1 arrows").arg(GetArrows());
+
+    if (GetEnduranceRestore() > 0)
+        return QString("Restores %1 ENDURANCE POINTS").arg(GetEnduranceRestore());
+
+    return "";
+}
+
 void Item::Use(QScriptEngine* engine, QScriptValue* functions)
 {
     QScriptValue objectValue = engine->newQObject(this);
