@@ -40,6 +40,7 @@ public:
 
 public slots:
     QString GetName() { return Name; }
+
     bool GetIsBackpackItem() { return !GetIsSpecial() && !GetIsWeapon(); }
 
     bool GetIsSpecial() { return GetBoolProperty("IsSpecial"); }
@@ -51,6 +52,9 @@ public slots:
     bool GetIsQuiver() { return GetBoolProperty("IsQuiver"); }
     void SetIsQuiver(bool value) { SetBoolProperty("IsQuiver", value); }
 
+    int GetArrows() { return GetProperty("Arrows").toInt(); }
+    void SetArrows(int value) { SetProperty("Arrows", QString::number(value)); }
+
     bool GetIsMeal() { return GetBoolProperty("IsMeal"); }
     void SetIsMeal(bool value) { SetBoolProperty("IsMeal", value); }
 
@@ -60,7 +64,7 @@ public slots:
     int GetEnduranceDelta() { return GetProperty("EnduranceDelta").toInt(); }
     void SetEnduranceDelta(int value) { SetProperty("EnduranceDelta", QString::number(value)); }
 
-    QString GetDescription() { return Description; }
+    QString GetDescription();
     void SetDescription(QString value) { Description = value; }
 
     int GetCombatskillDelta() { return GetProperty("CombatskillDelta").toInt(); }
