@@ -1,5 +1,6 @@
 #include "player.h"
 #include <QDebug>
+#include <stdlib.h>
 
 Player::Player(QObject *parent) :
     QObject(parent)
@@ -9,7 +10,6 @@ Player::Player(QObject *parent) :
     BaseEndurance = 0;
     Endurance = 0;
     GoldCrowns = 0;
-    Arrows = 0;
     KaiDisciplines.clear();    
     m_Backpack = true;
     m_CanHunt = true;
@@ -25,7 +25,6 @@ Player::Player(const Player& player) :
     BaseEndurance = player.BaseEndurance;
     Endurance = player.Endurance;
     GoldCrowns = player.GoldCrowns;
-    Arrows = player.Arrows;
     m_Backpack = player.m_Backpack;
     m_CanHunt = player.m_CanHunt;
 
@@ -407,6 +406,70 @@ void Player::SetGoldCrowns(int crowns)
         GoldCrowns = 0;
 }
 
+int Player::GetMaxArrows()
+{
+    int res = 0;
+    foreach (Item* i, Items){
+        if (i->GetIsSpecial() && i->GetIsQuiver())
+            res += 6;
+    }
+    return res;
+}
+
+int Player::GetArrows()
+{
+    int res = 0;
+    foreach (Item* i, Items){
+        if (i->GetIsSpecial() && i->GetIsQuiver())
+            res += i->GetArrows();
+    }
+    return res;
+}
+
+void Player::SetArrows(int value)
+{
+    int quivers = 0;
+    int arrows = 0;
+    foreach (Item* i, Items){
+        if (i->GetIsSpecial() && i->GetIsQuiver()){
+            quivers++;
+            arrows += i->GetArrows();
+        }
+    }
+
+    if (value == arrows)
+        return;
+
+    if (value > quivers * 6)
+        value = quivers * 6;
+    else if (value < 0)
+        value = 0;
+
+    int delta = value - arrows;
+    foreach (Item* i, Items){
+        if (i->GetIsSpecial() && i->GetIsQuiver()){
+            int absDelta = abs(delta);
+            if (delta < 0){
+                if (absDelta < i->GetArrows()){
+                    i->SetArrows(i->GetArrows() + delta);
+                    delta = 0;
+                }else{
+                    delta += i->GetArrows();
+                    i->SetArrows(0);
+                }
+            }else{
+                if (i->GetArrows() + absDelta <= 6){
+                    i->SetArrows(i->GetArrows() + delta);
+                    delta = 0;
+                }else{
+                    delta -= (6 - i->GetArrows());
+                    i->SetArrows(6);
+                }
+            }
+        }
+    }
+}
+
 bool Player::HasItem(QString name)
 {
     foreach(Item* i, Items){
@@ -575,13 +638,6 @@ void Player::SetHasBackpack(bool value)
     }
 }
 
-void Player::SetHasQuiver(bool value)
-{
-    m_Quiver = value;
-    if (!m_Quiver)
-        Arrows = 0;
-}
-
 bool Player::IsBackpackFull()
 {
     int size = 0;
@@ -658,6 +714,23 @@ bool Player::HasWeapon(QString name)
     return false;
 }
 
+bool Player::HasWeaponOfClass(QString wClass)
+{
+    int wc = Weapon::GetClass(wClass);
+    if (wc != Weapon::None){
+        foreach(Weapon* w, Weapons()){
+            if (w->Classes().contains(wc))
+                return true;
+        }
+    }
+    return false;
+}
+
+bool Player::CanUseBow()
+{
+    return HasWeaponOfClass("Bow") && GetArrows() > 0;
+}
+
 Weapon* Player::GetWeapon(QString name)
 {
     foreach(Weapon* w, Weapons()){
@@ -758,6 +831,15 @@ void Player::ClearProperties()
     Properties.clear();
 }
 
+bool Player::HasQuiver()
+{
+    foreach (Item* i, Items){
+        if (i->GetIsSpecial() && i->GetIsQuiver())
+            return true;
+    }
+    return false;
+}
+
 int Player::GetBowBonus(bool includeDisciplines)
 {
     int bonus = 0;
