@@ -16,7 +16,6 @@ public:
     int BaseEndurance;
     int Endurance;
 
-    int Arrows;
     int GoldCrowns;
     int TemporaryCombatSkillDelta;
 
@@ -44,7 +43,6 @@ public:
 private:
     bool m_Backpack;
     bool m_CanHunt;
-    bool m_Quiver;
 
 public slots:
     // Remove all disciplines (used at the beginning of a new serie when disciplines change)
@@ -101,8 +99,9 @@ public slots:
     Item* AddMeal(QString name);
     Item* AddHealingItem(QString name, int enduranceRestore);
 
-    int GetArrows() { return Arrows; }
-    void SetArrows(int value) { value <= 6 ? Arrows = value : Arrows = 6; }
+    int GetMaxArrows();
+    int GetArrows();
+    void SetArrows(int value);
 
     int GetGoldCrowns();
     void SetGoldCrowns(int);
@@ -131,8 +130,7 @@ public slots:
     bool IsBackpackFull();
     int GetBackpackFreeSpace();
 
-    bool HasQuiver() const { return m_Quiver; }
-    void SetHasQuiver(bool value);
+    bool HasQuiver();
     int GetBowBonus(bool includeDisciplines=true);
 
     int WeaponsCount();
@@ -142,6 +140,8 @@ public slots:
     Weapon* AddWeapon(QString name, QString classname);
     Weapon* AddSpecialWeapon(QString name, QString classname);
     bool HasWeapon(QString name);
+    bool HasWeaponOfClass(QString wClass);
+    bool CanUseBow();
     Weapon* GetWeapon(QString name);
     int GetFreeHands();
 
