@@ -100,7 +100,7 @@ void PickItemsWindow::ShowData(bool full)
             ui->layPickItems->addWidget(lbl, row, 0);
 
             lbl = new QLabel(this);
-            lbl->setText(i->Description);
+            lbl->setText(i->GetDescription());
             lbl->setWordWrap(true);
             ui->layPickItems->addWidget(lbl, row, 1);
 
@@ -125,7 +125,7 @@ void PickItemsWindow::ShowData(bool full)
         break;
     }
     ui->lblCrowns->setText(QString::number(m_Player->GetGoldCrowns()));
-    ui->lblArrows->setText(QString::number(m_Player->Arrows));
+    ui->lblArrows->setText(QString::number(m_Player->GetArrows()));
     ui->chkQuiver->setChecked(m_Player->HasQuiver());
     ui->pbnDropWeapon1->setEnabled(false);
     ui->pbnDropWeapon2->setEnabled(false);
@@ -233,17 +233,11 @@ void PickItemsWindow::CheckItemSlot(bool value)
                     msgBox.exec();
                     chk->setChecked(false);
                     return;
-                } else if (i->GetIsQuiver() && m_Player->HasQuiver()){
-                    QMessageBox msgBox(this);
-                    msgBox.setText("You have the quiver and cannot carry another one.");
-                    msgBox.exec();
-                    chk->setChecked(false);
-                    return;
                 }else if (!i->GetIsSpecial()){
                     if (i->GetIsArrow()){
                         if (!m_Player->HasQuiver()){
                             QMessageBox msgBox(this);
-                            msgBox.setText("You don't have the quiver and cannot carry arrows.");
+                            msgBox.setText("You don't have a quiver and cannot carry arrows.");
                             msgBox.exec();
                             chk->setChecked(false);
                             return;
@@ -293,8 +287,8 @@ void PickItemsWindow::DoneSlot()
         if (w)
             m_Player->Items.append(w);
         else{
-            if (i->GetIsQuiver()){
-                m_Player->SetHasQuiver(true);
+            if (i->GetIsArrow()){
+                m_Player->SetArrows(m_Player->GetArrows() + i->GetQuantity());
             }else if (i->GetIsBackpack()){
                 m_Player->SetHasBackpack(true);
             }else{
