@@ -16,7 +16,7 @@ class PickItemsWindow : public QDialog
     Q_OBJECT
 
 public:
-    explicit PickItemsWindow(QWidget *parent = 0, Player* player=0, int goldCrowns=0, QList<Item*>* items=0, int max=2);
+    explicit PickItemsWindow(QWidget *parent = 0, Player* player=0, int serie=Book::Kai, int goldCrowns=0, QList<Item*>* items=0, int max=2);
     ~PickItemsWindow();
 
     int GetPickedItemsCount() { return m_Selected.count(); }
@@ -27,6 +27,7 @@ private:
     QLabel* m_GoldCrownsLabel;
     QPushButton* m_GoldCrownsButton;
     RandomNumberPicker* m_RandomPicker;
+    int m_Serie;
     Player* m_Player;
     int m_GoldCrowns;
     QList<Item*>* m_List;
