@@ -83,7 +83,7 @@ void ShopWindow::ShowData()
         ui->layPickItems->addWidget(lbl, row, 0);
 
         lbl = new QLabel(this);
-        lbl->setText(i->Description);
+        lbl->setText(i->GetDescription());
         lbl->setWordWrap(true);
         ui->layPickItems->addWidget(lbl, row, 1);
 
@@ -96,8 +96,7 @@ void ShopWindow::ShowData()
         pbn->setObjectName(QString::number(index++));
         pbn->setText("Buy");
         if (i->Price > m_Player->GetGoldCrowns() ||
-            (i->GetIsBackpack() && m_Player->HasBackpack()) ||
-            (i->GetIsQuiver() && m_Player->HasQuiver()))
+            (i->GetIsBackpack() && m_Player->HasBackpack()))
             pbn->setEnabled(false);
         pbn->setMaximumSize(75, 50);
         connect(pbn, SIGNAL(clicked()), this, SLOT(BuyItemSlot()));
@@ -117,7 +116,7 @@ void ShopWindow::ShowData()
     }
 
     ui->lblCrowns->setText(QString::number(m_Player->GetGoldCrowns()));
-    ui->lblArrows->setText(QString::number(m_Player->Arrows));
+    ui->lblArrows->setText(QString::number(m_Player->GetArrows()));
     ui->chkQuiver->setChecked(m_Player->HasQuiver());
     ui->pbnDropWeapon1->setEnabled(false);
     ui->pbnDropWeapon2->setEnabled(false);
@@ -223,7 +222,7 @@ void ShopWindow::BuyItemSlot()
             return;
         }
 
-        if (i->GetIsArrow() && m_Player->Arrows == 6){
+        if (i->GetIsArrow() && m_Player->GetArrows() == m_Player->GetMaxArrows()){
             QMessageBox msgBox(this);
             msgBox.setText("You cannot carry more arrows.");
             msgBox.exec();
@@ -251,10 +250,8 @@ void ShopWindow::BuyItemSlot()
         if (i->IsWeapon())
             m_Player->Items.append((Weapon*)i);
         else{
-            if (i->GetIsQuiver())
-                m_Player->SetHasQuiver(true);
-            else if (i->GetIsArrow())
-                m_Player->Arrows += i->GetQuantity();
+            if (i->GetIsArrow())
+                m_Player->SetArrows(m_Player->GetArrows() + i->GetQuantity());
             else if (i->GetIsBackpack())
                 m_Player->SetHasBackpack(true);
             else
