@@ -125,7 +125,7 @@ void StatusWindow::ShowData()
             ui->laySectionItems->addWidget(lbl, row, 0);
 
             lbl = new QLabel(this);
-            lbl->setText(i->Description);
+            lbl->setText(i->GetDescription());
             lbl->setWordWrap(true);
             ui->laySectionItems->addWidget(lbl, row, 1);
 
@@ -144,7 +144,7 @@ void StatusWindow::ShowData()
     ui->lblCrowns->setText(QString("%1/50").arg(m_Player->GoldCrowns));
     ui->lblMeals->setText(QString::number(m_Player->MealsCount()));
     ui->chkQuiver->setChecked(m_Player->HasQuiver());
-    ui->lblArrows->setText(QString::number(m_Player->Arrows));
+    ui->lblArrows->setText(QString::number(m_Player->GetArrows()));
 
     QList<Weapon*> weapons = m_Player->Weapons();
     ui->pbnDropWeapon1->setEnabled(false);
@@ -199,7 +199,7 @@ void StatusWindow::ShowData()
             ui->layEquippedWeapons->addWidget(lbl, row, 0);
 
             lbl = new QLabel(this);
-            lbl->setText(w->Description);
+            lbl->setText(w->GetDescription());
             lbl->setWordWrap(true);
             ui->layEquippedWeapons->addWidget(lbl, row, 1);
             row++;
@@ -222,7 +222,7 @@ void StatusWindow::ShowData()
             ui->layEquippedArmor->addWidget(lbl, row, 0);
 
             lbl = new QLabel(this);
-            lbl->setText(i->Description);
+            lbl->setText(i->GetDescription());
             lbl->setWordWrap(true);
             ui->layEquippedArmor->addWidget(lbl, row, 1);
             row++;
@@ -310,7 +310,7 @@ void StatusWindow::ShowData()
                 ui->layItems->addWidget(lbl, row, 1);
 
                 lbl = new QLabel(this);
-                lbl->setText(i->Description);
+                lbl->setText(i->GetDescription());
                 lbl->setWordWrap(true);
                 ui->layItems->addWidget(lbl, row, 2);
 
@@ -387,7 +387,7 @@ void StatusWindow::ShowData()
             ui->laySpecialItems->addWidget(lbl, row, 0);
 
             lbl = new QLabel(this);
-            lbl->setText(i->Description);
+            lbl->setText(i->GetDescription());
             lbl->setWordWrap(true);
             ui->laySpecialItems->addWidget(lbl, row, 1);
 
@@ -567,18 +567,18 @@ void StatusWindow::TakeItemSlot()
         if (i->GetIsArrow()){
             if (!m_Player->HasQuiver()){
                 QMessageBox msgBox(this);
-                msgBox.setText("You don't have the quiver and cannot carry arrows.");
+                msgBox.setText("You don't have a quiver and cannot carry arrows.");
                 msgBox.exec();
                 return;
             }
-            if (m_Player->Arrows == 6){
+            if (m_Player->GetArrows() == m_Player->GetMaxArrows()){
                 QMessageBox msgBox(this);
                 msgBox.setText("You cannot carry more arrows.");
                 msgBox.exec();
                 return;
             }
 
-            m_Player->Arrows += i->GetQuantity();
+            m_Player->SetArrows(m_Player->GetArrows() + i->GetQuantity());
             m_Section->Items.removeOne(i);
             ShowData();
         }else{
